Credits
#######

This project was initiated and is still mainly maintained by **Dieter
Werthmüller**. However, it is a community effort as many people helped to
improve it over time. The copyright is therefore attributed to «The empymod
Developers», which includes everyone involved in the project.

Code contributors:

- `Dieter Werthmüller <https://github.com/prisae>`_


There are various other ways how people have contributed. In the following some
particular credits.

Special thanks to

- **Jürg Hunziker**, **Kerry Key**, and **Evert Slob** for answering all my
  questions regarding their codes and publications
  (`Hunziker et al., 2015 <https://doi.org/10.1190/geo2013-0411.1>`_,
  `Key, 2009 <https://doi.org/10.1190/1.3058434>`_,
  `Key, 2012 <https://doi.org/10.1190/geo2011-0237.1>`_,
  `Slob et al., 2010 <https://doi.org/10.2528/PIER10052807>`_).

- **Evert Slob** for the feedback and interaction during the creation of the
  add-on ``tmtemod``, which was developed for the creation of
  `github.com/empymod/csem-ziolkowski-and-slob
  <https://github.com/empymod/csem-ziolkowski-and-slob>`_.

- **Kerry Key** and **Evert Slob** for their inputs and feedback during the
  development of the add-on ``fdesign`` (see
  `github.com/empymod/article-fdesign
  <https://github.com/empymod/article-fdesign>`_).

- **The electromagnetic group** of Aleksander Mousatov at the Mexican Petroleum
  Institute, Mexico City (see note below).


Many more helped through their feedback, feature request, bug reports etc. A
certainly incomplete list (get in touch if you think you should appear here):

- `Seogi Kang <https://github.com/sgkang>`_
- Svein-Erik Hamran
- Peter van der Sman
- `Ralph-Uwe Börner <https://github.com/ruboerner>`_
- `Leon Foks <https://github.com/leonfoks>`_


.. note::

    This software was initially (till 01/2017) developed with funding from *The
    Mexican National Council of Science and Technology* (*Consejo Nacional de
    Ciencia y Tecnología*, https://www.conacyt.gob.mx), carried out at *The
    Mexican Institute of Petroleum IMP* (*Instituto Mexicano del Petróleo*,
    https://www.gob.mx/imp).
